package com.ruoyi.project.business.service.quotation.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import javax.annotation.Resource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.business.mapper.quotation.TqSpecificationParabarDetailMapper;
import com.ruoyi.project.business.domain.TqSpecificationParabarDetail;
import com.ruoyi.project.business.service.quotation.ITqSpecificationParabarDetailService;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2024-05-10
 */
@Service
public class TqSpecificationParabarDetailServiceImpl extends
    ServiceImpl<TqSpecificationParabarDetailMapper, TqSpecificationParabarDetail> implements
    ITqSpecificationParabarDetailService {

    @Resource
    private TqSpecificationParabarDetailMapper tqSpecificationParabarDetailMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public TqSpecificationParabarDetail selectTqSpecificationParabarDetailById(Long id) {
        return tqSpecificationParabarDetailMapper.selectTqSpecificationParabarDetailById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tqSpecificationParabarDetail 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TqSpecificationParabarDetail> selectTqSpecificationParabarDetailList(
        TqSpecificationParabarDetail tqSpecificationParabarDetail) {
        return tqSpecificationParabarDetailMapper.selectTqSpecificationParabarDetailList(tqSpecificationParabarDetail);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param tqSpecificationParabarDetail 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTqSpecificationParabarDetail(TqSpecificationParabarDetail tqSpecificationParabarDetail) {
        tqSpecificationParabarDetail.setCreateTime(DateUtils.getNowDate());
        return tqSpecificationParabarDetailMapper.insertTqSpecificationParabarDetail(tqSpecificationParabarDetail);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param tqSpecificationParabarDetail 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTqSpecificationParabarDetail(TqSpecificationParabarDetail tqSpecificationParabarDetail) {
        tqSpecificationParabarDetail.setUpdateTime(DateUtils.getNowDate());
        return tqSpecificationParabarDetailMapper.updateTqSpecificationParabarDetail(tqSpecificationParabarDetail);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTqSpecificationParabarDetailByIds(Long[] ids) {
        return tqSpecificationParabarDetailMapper.deleteTqSpecificationParabarDetailByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTqSpecificationParabarDetailById(Long id) {
        return tqSpecificationParabarDetailMapper.deleteTqSpecificationParabarDetailById(id);
    }
}
