package com.ruoyi.project.business.controller.quotation;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.business.domain.TqSpecificationParabarDetail;
import com.ruoyi.project.business.service.quotation.ITqSpecificationParabarDetailService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-05-10
 */
@RestController
@RequestMapping("/business/specification/parabar/detail")
public class TqSpecificationParabarDetailController extends BaseController
{
    @Autowired
    private ITqSpecificationParabarDetailService tqSpecificationParabarDetailService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:detail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TqSpecificationParabarDetail tqSpecificationParabarDetail)
    {
        startPage();
        List<TqSpecificationParabarDetail> list = tqSpecificationParabarDetailService.selectTqSpecificationParabarDetailList(tqSpecificationParabarDetail);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:detail:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TqSpecificationParabarDetail tqSpecificationParabarDetail)
    {
        List<TqSpecificationParabarDetail> list = tqSpecificationParabarDetailService.selectTqSpecificationParabarDetailList(tqSpecificationParabarDetail);
        ExcelUtil<TqSpecificationParabarDetail> util = new ExcelUtil<TqSpecificationParabarDetail>(TqSpecificationParabarDetail.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:detail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tqSpecificationParabarDetailService.selectTqSpecificationParabarDetailById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:detail:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TqSpecificationParabarDetail tqSpecificationParabarDetail)
    {
        return toAjax(tqSpecificationParabarDetailService.insertTqSpecificationParabarDetail(tqSpecificationParabarDetail));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:detail:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TqSpecificationParabarDetail tqSpecificationParabarDetail)
    {
        return toAjax(tqSpecificationParabarDetailService.updateTqSpecificationParabarDetail(tqSpecificationParabarDetail));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:detail:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tqSpecificationParabarDetailService.deleteTqSpecificationParabarDetailByIds(ids));
    }
}
